@@ -3,14 +3,14 @@ package Alien::Base;
 use strict;
 use warnings;
 use Carp;
-use Path::Tiny ();
+use File::ShareDir ();
+use File::Spec;
 use Scalar::Util qw/blessed/;
 use Capture::Tiny 0.17 qw/capture_merged/;
 use Text::ParseWords qw/shellwords/;
 
 # ABSTRACT: Base classes for Alien:: modules
-our $VERSION = '0.98_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.73'; # VERSION
 
 
 sub import {
@@ -64,29 +64,6 @@ sub import {
 }
 
 
-sub _dist_dir ($)
-{
-  my($dist_name) = @_;
-  
-  my @pm = split /-/, $dist_name;
-  $pm[-1] .= ".pm";
-  
-  foreach my $inc (@INC)
-  {
-    my $pm = Path::Tiny->new($inc, @pm);
-    if(-f $pm)
-    {
-      my $share = Path::Tiny->new($inc, qw( auto share dist ), $dist_name );
-      if(-d $share)
-      {
-        return $share->absolute->stringify;
-      }
-      last;
-    }
-  }
-  Carp::croak("unable to find dist share directory for $dist_name");
-}
-
 sub dist_dir {
   my $class = shift;
 
@@ -95,7 +72,7 @@ sub dist_dir {
 
   my $dist_dir = 
     $class->config('finished_installing') 
-      ? _dist_dir $dist
+      ? File::ShareDir::dist_dir($dist) 
       : $class->config('working_directory');
 
   croak "Failed to find share dir for dist '$dist'"
@@ -158,13 +135,9 @@ sub libs_static {
 
 sub version {
   my $self = shift;
-  return $self->runtime_prop
-    ? $self->runtime_prop->{version}
-    : do {
-      my $version = $self->config('version');
-      chomp $version;
-      $version;
-    };
+  my $version = $self->config('version');
+  chomp $version;
+  return $version;
 }
 
 
@@ -330,13 +303,13 @@ sub dynamic_libs {
   } else {
   
     my $dir = $class->dist_dir;
-    my $dynamic = Path::Tiny->new($class->dist_dir, 'dynamic');
+    my $dynamic = File::Spec->catfile($class->dist_dir, 'dynamic');
     
     if(-d $dynamic)
     {
       return FFI::CheckLib::find_lib(
         lib        => '*',
-        libpath    => "$dynamic",
+        libpath    => $dynamic,
         systempath => [],
       );
     }
@@ -362,8 +335,8 @@ sub bin_dir {
   }
   else
   {
-    my $dir = Path::Tiny->new($class->dist_dir, 'bin');
-    return -d $dir ? ("$dir") : ();
+    my $dir = File::Spec->catfile($class->dist_dir, 'bin');
+    return -d $dir ? ($dir) : ();
   }
 }
 
@@ -408,11 +381,13 @@ sub Inline {
     $alien_build_config_cache{$class} ||= do {
       my $dist = ref $class ? ref $class : $class;
       $dist =~ s/::/-/g;
-      my $dist_dir = eval { _dist_dir $dist };
+      my $dist_dir = eval { File::ShareDir::dist_dir($dist) };
       return if $@;
-      my $alien_json = Path::Tiny->new($dist_dir, '_alien', 'alien.json');
+      my $alien_json = File::Spec->catfile($dist_dir, '_alien', 'alien.json');
       return unless -r $alien_json;
-      my $json = $alien_json->slurp;
+      open my $fh, '<', $alien_json;
+      my $json = do { local $/; <$fh> };
+      close $fh;
       require JSON::PP;
       my $config = JSON::PP::decode_json($json);
       $config->{distdir} = $dist_dir;
@@ -433,7 +408,7 @@ Alien::Base - Base classes for Alien:: modules
 
 =head1 VERSION
 
-version 0.98_01
+version 0.73
 
 =head1 SYNOPSIS
 
