@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Add dependencies to library and header search path
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.73'; # VERSION
 
 
 has aliens => {};
@@ -87,6 +87,9 @@ sub init
     gather_share => sub {
       my($build) = @_;
       
+      $build->runtime_prop->{libs}        = '' unless defined $build->runtime_prop->{libs};
+      $build->runtime_prop->{libs_static} = '' unless defined $build->runtime_prop->{libs_static};
+
       if($self->public_l)
       {
         $build->runtime_prop->{$_} = join(' ', @{ $build->install_prop->{plugin_build_searchdep_libs} }) . ' ' . $build->runtime_prop->{$_}
@@ -98,6 +101,8 @@ sub init
 
       if($self->public_I)
       {
+        $build->runtime_prop->{cflags}        = '' unless defined $build->runtime_prop->{cflags};
+        $build->runtime_prop->{cflags_static} = '' unless defined $build->runtime_prop->{cflags_static};
         $build->runtime_prop->{$_} = join(' ', @{ $build->install_prop->{plugin_build_searchdep_cflags} }) . ' ' . $build->runtime_prop->{$_}
           for qw( cflags cflags_static );
       }
@@ -119,7 +124,7 @@ Alien::Build::Plugin::Build::SearchDep - Add dependencies to library and header
 
 =head1 VERSION
 
-version 0.66
+version 0.73
 
 =head1 SYNOPSIS
 
@@ -161,6 +166,34 @@ Roy Storey
 
 Ilya Pavlov
 
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Juan Julián Merelo Guervós (JJ)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
