@@ -7,7 +7,7 @@ use Path::Tiny ();
 use Alien::Build::Util qw( _mirror );
 
 # ABSTRACT: Core download plugin
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.73'; # VERSION
 
 
 sub _hook
@@ -47,14 +47,13 @@ sub _hook
     }
   }
 
-  my $tmp = Alien::Build::TempDir->new($build, "download");
-
   if($res->{type} eq 'file')
   {
     my $alienfile = $res->{filename};
     $build->log("downloaded $alienfile");
     if($res->{content})
     {
+      my $tmp = Alien::Build::TempDir->new($build, "download");
       my $path = Path::Tiny->new("$tmp/$alienfile");
       $path->spew_raw($res->{content});
       $build->install_prop->{download} = $path->stringify;
@@ -63,21 +62,37 @@ sub _hook
     }
     elsif($res->{path})
     {
-      my $from = Path::Tiny->new($res->{path});
-      my $to   = Path::Tiny->new("$tmp/@{[ $from->basename ]}");
-      if(-d $res->{path})
+      if(defined $res->{tmp} && !$res->{tmp})
       {
-        _mirror $from, $to;
+        if(-e $res->{path})
+        {
+          $build->install_prop->{download} = $res->{path};
+          $build->install_prop->{complete}->{download} = 1;
+        }
+        else
+        {
+          die "not a file or directory: @{[ $res->{path} ]}";
+        }
       }
       else
       {
-        require File::Copy;
-        File::Copy::copy(
-          "$from" => "$to",
-        ) || die "copy $from => $to failed: $!";
+        my $from = Path::Tiny->new($res->{path});
+        my $tmp = Alien::Build::TempDir->new($build, "download");
+        my $to   = Path::Tiny->new("$tmp/@{[ $from->basename ]}");
+        if(-d $res->{path})
+        {
+          _mirror $from, $to;
+        }
+        else
+        {
+          require File::Copy;
+          File::Copy::copy(
+            "$from" => "$to",
+          ) || die "copy $from => $to failed: $!";
+        }
+        $build->install_prop->{download} = $to->stringify;
+        $build->install_prop->{complete}->{download} = 1;
       }
-      $build->install_prop->{download} = $to->stringify;
-      $build->install_prop->{complete}->{download} = 1;
       return $build;
     }
     die "file without content or path";
@@ -106,7 +121,7 @@ Alien::Build::Plugin::Core::Download - Core download plugin
 
 =head1 VERSION
 
-version 0.66
+version 0.73
 
 =head1 SYNOPSIS
 
@@ -133,6 +148,34 @@ Roy Storey
 
 Ilya Pavlov
 
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Juan Julián Merelo Guervós (JJ)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
