@@ -3,10 +3,11 @@ package Alien::Build::Plugin::PkgConfig::Negotiate;
 use strict;
 use warnings;
 use Alien::Build::Plugin;
+use Config;
 use Carp ();
 
 # ABSTRACT: Package configuration negotiation plugin
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.73'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -19,6 +20,8 @@ has minimum_version => undef;
 sub _pick
 {
   my($class) = @_;
+
+  return $ENV{ALIEN_BUILD_PKG_CONFIG} if $ENV{ALIEN_BUILD_PKG_CONFIG};
   
   if(eval q{ use PkgConfig::LibPkgConf 0.04; 1 })
   {
@@ -28,7 +31,10 @@ sub _pick
   require Alien::Build::Plugin::PkgConfig::CommandLine;
   if(Alien::Build::Plugin::PkgConfig::CommandLine->new(pkg_name => 'foo')->bin_name)
   {
-    return 'PkgConfig::CommandLine';
+    unless($^O eq 'solaris' && $Config{ptrsize} == 8)
+    {
+      return 'PkgConfig::CommandLine';
+    }
   }
   
   return 'PkgConfig::PP';
@@ -37,8 +43,11 @@ sub _pick
 sub init
 {
   my($self, $meta) = @_;
+
+  my $plugin = $self->_pick;
+  Alien::Build->log("Using PkgConfig plugin: $plugin");
     
-  $self->subplugin($self->_pick,
+  $self->subplugin($plugin,
     pkg_name        => $self->pkg_name,
     minimum_version => $self->minimum_version,
   )->init($meta);
@@ -60,7 +69,7 @@ Alien::Build::Plugin::PkgConfig::Negotiate - Package configuration negotiation p
 
 =head1 VERSION
 
-version 0.66
+version 0.73
 
 =head1 SYNOPSIS
 
@@ -84,6 +93,17 @@ The package name.
 
 The minimum required version that is acceptable version as provided by the system.
 
+=head1 ENVIRONMENT
+
+=over 4
+
+=item ALIEN_BUILD_PKG_CONFIG
+
+If set, this plugin will be used instead of the build in logic
+which attempts to automatically pick the best plugin.
+
+=back
+
 =head1 SEE ALSO
 
 L<Alien::Build>, L<alienfile>, L<Alien::Build::MM>, L<Alien>
@@ -100,6 +120,34 @@ Roy Storey
 
 Ilya Pavlov
 
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Juan Julián Merelo Guervós (JJ)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
