@@ -19,7 +19,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.73'; # VERSION
 
 
 our @aliens;
@@ -133,6 +133,18 @@ sub _flags
     : $class->$method;
 }
 
+{
+  my $seen = 0;
+  sub _warn_cpp
+  {
+    return if $seen;
+    my $ctx = context();
+    $ctx->diag("Test::Alien xs_ok C++ is considered experimental");
+    $ctx->release;
+    $seen++;
+  }
+}
+
 sub xs_ok
 {
   my $cb;
@@ -157,6 +169,16 @@ sub xs_ok
   # modify it.
   $xs->{xs} = "@{[ $xs->{xs} ]}";
   $xs->{pxs} ||= {};
+  $xs->{cbuilder_compile} ||= {};
+  $xs->{link_compile}     ||= {};
+
+  if($xs->{cpp} || $xs->{'C++'})
+  {
+    _warn_cpp();
+    $xs->{pxs}->{'C++'} = 1;
+    $xs->{cbuilder_compile}->{'C++'} = 1;
+  }
+
   my $verbose = $xs->{verbose};
   my $ok = 1;
   my @diag;
@@ -236,6 +258,7 @@ sub xs_ok
         $cb->compile(
           source               => $c_filename,
           extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
+          %{ $xs->{cbuilder_compile} },
         );
       };
       ($obj, $@);
@@ -262,6 +285,7 @@ sub xs_ok
             objects            => [$obj],
             module_name        => $module,
             extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
+            %{ $xs->{cbuilder_link} },
           );
         };
         ($lib, $@);
@@ -552,7 +576,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.66
+version 0.73
 
 =head1 SYNOPSIS
 
@@ -759,12 +783,26 @@ The XS code.  This is the only required element.
 
 =item pxs
 
-The L<ExtUtils::ParseXS> arguments passes as a hash reference.
+Extra L<ExtUtils::ParseXS> arguments passed in as a hash reference.
+
+=item cbuilder_compile
+
+Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
+
+=item cbuilder_link
+
+Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
 
 =item verbose
 
 Spew copious debug information via test note.
 
+=item C++ or cpp
+
+[EXPERIMENTAL]
+
+XS should be compiled as C++.
+
 =back
 
 You can use the C<with_subtest> keyword to conditionally
@@ -874,6 +912,34 @@ Roy Storey
 
 Ilya Pavlov
 
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Juan Julián Merelo Guervós (JJ)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
